@@ -2,7 +2,7 @@ package Test2::Compare;
 use strict;
 use warnings;
 
-our $VERSION = '0.000077';
+our $VERSION = '0.000119';
 
 use Scalar::Util qw/blessed/;
 use Test2::Util qw/try/;
@@ -118,7 +118,7 @@ sub _convert {
     return Test2::Compare::Undef->new()
         unless defined $thing;
 
-    if ($thing && blessed($thing) && $thing->isa('Test2::Compare::Base')) {
+    if (blessed($thing) && $thing->isa('Test2::Compare::Base')) {
         if ($config->{implicit_end} && $thing->can('set_ending') && !defined $thing->ending) {
             my $clone = $thing->clone;
             $clone->set_ending('implicit');
@@ -152,7 +152,7 @@ sub _convert {
     return Test2::Compare::Regex->new(input => $thing)
         if $type eq 'REGEXP';
 
-    if ($type eq 'SCALAR') {
+    if ($type eq 'SCALAR' || $type eq 'VSTRING') {
         my $nested = _convert($$thing, $config);
         return Test2::Compare::Scalar->new(item => $nested);
     }
@@ -419,7 +419,7 @@ L<Test2::Compare::Base> subclass.
 =head1 SOURCE
 
 The source code repository for Test2-Suite can be found at
-F<http://github.com/Test-More/Test2-Suite/>.
+F<https://github.com/Test-More/Test2-Suite/>.
 
 =head1 MAINTAINERS
 
@@ -439,7 +439,7 @@ F<http://github.com/Test-More/Test2-Suite/>.
 
 =head1 COPYRIGHT
 
-Copyright 2016 Chad Granum E<lt>exodist@cpan.orgE<gt>.
+Copyright 2018 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
