@@ -4,9 +4,9 @@ use warnings;
 
 use base 'Test2::Compare::Base';
 
-our $VERSION = '0.000077';
+our $VERSION = '0.000119';
 
-use Test2::Util::HashBase qw/ending items/;
+use Test2::Util::HashBase qw/ending meta items/;
 
 use Carp qw/croak confess/;
 use Scalar::Util qw/reftype looks_like_number/;
@@ -21,6 +21,8 @@ sub init {
 
 sub name { '<BAG>' }
 
+sub meta_class  { 'Test2::Compare::Meta' }
+
 sub verify {
     my $self = shift;
     my %params = @_;
@@ -32,6 +34,12 @@ sub verify {
     return 1;
 }
 
+sub add_prop {
+    my $self = shift;
+    $self->{+META} = $self->meta_class->new unless defined $self->{+META};
+    $self->{+META}->add_prop(@_);
+}
+
 sub add_item {
     my $self = shift;
     my $check = pop;
@@ -53,6 +61,9 @@ sub deltas {
     my @list = @$got;
     my %unmatched = map { $_ => $list[$_] } 0..$#list;
 
+    my $meta     = $self->{+META};
+    push @deltas => $meta->deltas(%params) if defined $meta;
+
     while (@items) {
         my $item = shift @items;
 
@@ -60,6 +71,7 @@ sub deltas {
 
         my $match = 0;
         for my $idx (0..$#list) {
+            next unless exists $unmatched{$idx};
             my $val = $list[$idx];
             my $deltas = $check->run(
                 id      => [ARRAY => $idx],
@@ -168,7 +180,7 @@ arrayref.
 =head1 SOURCE
 
 The source code repository for Test2-Suite can be found at
-F<http://github.com/Test-More/Test2-Suite/>.
+F<https://github.com/Test-More/Test2-Suite/>.
 
 =head1 MAINTAINERS
 
@@ -192,9 +204,9 @@ F<http://github.com/Test-More/Test2-Suite/>.
 
 =head1 COPYRIGHT
 
-Copyright 2016 Chad Granum E<lt>exodist@cpan.orgE<gt>.
+Copyright 2018 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
-Copyright 2016 Gianni Ceccarelli E<lt>dakkar@thenautilus.netE<gt>
+Copyright 2018 Gianni Ceccarelli E<lt>dakkar@thenautilus.netE<gt>
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
