@@ -2,7 +2,7 @@ package Test2::Compare::Base;
 use strict;
 use warnings;
 
-our $VERSION = '0.000077';
+our $VERSION = '0.000119';
 
 use Carp qw/confess croak/;
 use Scalar::Util qw/blessed/;
@@ -13,6 +13,7 @@ use Test2::Compare::Delta();
 sub MAX_CYCLES() { 75 }
 
 use Test2::Util::HashBase qw{builder _file _lines _info called};
+use Test2::Util::Ref qw/render_ref/;
 
 {
     no warnings 'once';
@@ -93,17 +94,19 @@ sub run {
     my $exists = $params{exists};
     my $got = $exists ? $params{got} : undef;
 
+    my $gotname = render_ref($got);
+
     # Prevent infinite cycles
-    if ($got && ref $got) {
+    if (defined($got) && ref $got) {
         die "Cycle detected in comparison, aborting"
-            if $seen->{$got} && $seen->{$got} >= MAX_CYCLES;
-        $seen->{$got}++;
+            if $seen->{$gotname} && $seen->{$gotname} >= MAX_CYCLES;
+        $seen->{$gotname}++;
     }
 
     my $ok = $self->verify(%params);
     my @deltas = $ok ? $self->deltas(%params) : ();
 
-    $seen->{$got}-- if $got && ref $got;
+    $seen->{$gotname}-- if defined $got && ref $got;
 
     return if $ok && !@deltas;
 
@@ -219,7 +222,7 @@ to prevent cycles.
 =head1 SOURCE
 
 The source code repository for Test2-Suite can be found at
-F<http://github.com/Test-More/Test2-Suite/>.
+F<https://github.com/Test-More/Test2-Suite/>.
 
 =head1 MAINTAINERS
 
@@ -239,7 +242,7 @@ F<http://github.com/Test-More/Test2-Suite/>.
 
 =head1 COPYRIGHT
 
-Copyright 2016 Chad Granum E<lt>exodist@cpan.orgE<gt>.
+Copyright 2018 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
