@@ -4,7 +4,7 @@ use warnings;
 
 use base 'Test2::Compare::Base';
 
-our $VERSION = '0.000077';
+our $VERSION = '0.000119';
 
 use Test2::Util::HashBase qw/code name operator/;
 
@@ -64,8 +64,8 @@ provides a way for you to write custom checks for fields in deep comparisons.
         name => 'IsRef',
         operator => 'ref(...)',
         code => sub {
-            my ($got, $exists, $operator, $name) = @_;
-            return ref($got) ? 1 : 0;
+            my %args = @_;
+            return $args{got} ? 1 : 0;
         },
     );
 
@@ -85,35 +85,36 @@ provides a way for you to write custom checks for fields in deep comparisons.
 
 =head1 ARGUMENTS
 
-Your custom sub will be passed 4 arguments:
+Your custom sub will be passed 4 arguments in a hash:
 
     code => sub {
-        my ($got, $exists, $operator, $name) = @_;
-        return ref($got) ? 1 : 0;
+        my %args = @_;
+        # provides got, exists, operator, name
+        return ref($args{got}) ? 1 : 0;
     },
 
-C<$_> is also localized to C<$got> to make it easier for those who need to use
+C<$_> is also localized to C<got> to make it easier for those who need to use
 regexes.
 
 =over 4
 
-=item $got
+=item got
 
 =item $_
 
 The value to be checked.
 
-=item $exists
+=item exists
 
-This will be a boolean. This will be true if C<$got> exists at all. If
-C<$exists> is false then it means C<$got> is not simply undef, but doesn't
+This will be a boolean. This will be true if C<got> exists at all. If
+C<exists> is false then it means C<got> is not simply undef, but doesn't
 exist at all (think checking the value of a hash key that does not exist).
 
-=item $operator
+=item operator
 
 The operator specified at construction.
 
-=item $name
+=item name
 
 The name provided at construction.
 
@@ -142,7 +143,7 @@ Returns the operator provided at construction.
 =head1 SOURCE
 
 The source code repository for Test2-Suite can be found at
-F<http://github.com/Test-More/Test2-Suite/>.
+F<https://github.com/Test-More/Test2-Suite/>.
 
 =head1 MAINTAINERS
 
@@ -162,7 +163,7 @@ F<http://github.com/Test-More/Test2-Suite/>.
 
 =head1 COPYRIGHT
 
-Copyright 2016 Chad Granum E<lt>exodist@cpan.orgE<gt>.
+Copyright 2018 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
