@@ -2,7 +2,7 @@ package Test2::Suite;
 use strict;
 use warnings;
 
-our $VERSION = '0.000077';
+our $VERSION = '0.000119';
 
 1;
 
@@ -59,7 +59,7 @@ also produces undesirable side effects.
 
 =item Test2::V#
 
-These does not live in the bundle namespace as they are the primary ways to use
+These do not live in the bundle namespace as they are the primary ways to use
 Test2::Suite.
 
 The current latest is L<Test2::V0>.
@@ -216,6 +216,12 @@ This exports tools for validating and comparing references.
 
 See L<Test2::Tools::Ref> for complete documentation.
 
+=item Spec
+
+This is an RSPEC implementation with concurrency support.
+
+See L<Test2::Tools::Spec> for more details.
+
 =item Subtest
 
 This exports tools for running subtests.
@@ -333,6 +339,8 @@ See L<Test2::Require::Threads> for complete documentation.
 See the L<Test2> documentation for a namespace map. Everything in this
 distribution uses L<Test2>.
 
+L<Test2::Manual> is the Test2 Manual.
+
 =head1 CONTACTING US
 
 Many Test2 developers and users lurk on L<irc://irc.perl.org/#perl>. We also
@@ -344,7 +352,7 @@ E<lt>exodist@cpan.orgE<gt>.
 =head1 SOURCE
 
 The source code repository for Test2-Suite can be found at
-F<http://github.com/Test-More/Test2-Suite/>.
+F<https://github.com/Test-More/Test2-Suite/>.
 
 =head1 MAINTAINERS
 
@@ -364,7 +372,7 @@ F<http://github.com/Test-More/Test2-Suite/>.
 
 =head1 COPYRIGHT
 
-Copyright 2016 Chad Granum E<lt>exodist@cpan.orgE<gt>.
+Copyright 2018 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
