@@ -2,7 +2,7 @@ package Test2::Tools::Compare;
 use strict;
 use warnings;
 
-our $VERSION = '0.000077';
+our $VERSION = '0.000119';
 
 use Carp qw/croak/;
 use Scalar::Util qw/reftype/;
@@ -21,6 +21,7 @@ use Test2::Compare::Bag();
 use Test2::Compare::Bool();
 use Test2::Compare::Custom();
 use Test2::Compare::Event();
+use Test2::Compare::Float();
 use Test2::Compare::Hash();
 use Test2::Compare::Meta();
 use Test2::Compare::Number();
@@ -44,6 +45,7 @@ use Test2::Compare::Wildcard();
     'Test2::Compare::Bool'          => 1,
     'Test2::Compare::Custom'        => 1,
     'Test2::Compare::Event'         => 1,
+    'Test2::Compare::Float'         => 1,
     'Test2::Compare::Hash'          => 1,
     'Test2::Compare::Meta'          => 1,
     'Test2::Compare::Number'        => 1,
@@ -63,7 +65,7 @@ our @EXPORT = qw/is like/;
 our @EXPORT_OK = qw{
     is like isnt unlike
     match mismatch validator
-    hash array bag object meta meta_check number string subset bool
+    hash array bag object meta meta_check number float rounded within string subset bool
     in_set not_in_set check_set
     item field call call_list call_hash prop check all_items all_keys all_vals all_values
     etc end filter_items
@@ -200,7 +202,7 @@ sub D() {
 sub DF() {
     my @caller = caller;
     Test2::Compare::Custom->new(
-        code => sub { defined $_ && ! $_ ? 1 : 0 }, name => 'DEFINED BUT FALSE', operator => 'DEFINED() && FALSE()',
+        code => sub { defined $_ && ( ! ref $_ && ! $_ ) ? 1 : 0 }, name => 'DEFINED BUT FALSE', operator => 'DEFINED() && FALSE()',
         file => $caller[1],
         lines => [$caller[2]],
     );
@@ -236,7 +238,7 @@ sub F() {
 sub FDNE() {
     my @caller = caller;
     Test2::Compare::Custom->new(
-        code => sub { $_ ? 0 : 1 }, name => 'FALSE', operator => 'FALSE() || !exists',
+        code => sub { defined $_ && ( ref $_ || $_ ) ? 0 : 1 }, name => 'FALSE', operator => 'FALSE() || !exists',
         file => $caller[1],
         lines => [$caller[2]],
     );
@@ -245,7 +247,7 @@ sub FDNE() {
 sub T() {
     my @caller = caller;
     Test2::Compare::Custom->new(
-        code => sub { $_ ? 1 : 0 }, name => 'TRUE', operator => 'TRUE()',
+        code => sub { defined $_ && ( ref $_ || $_ ) ? 1 : 0 }, name => 'TRUE', operator => 'TRUE()',
         file => $caller[1],
         lines => [$caller[2]],
     );
@@ -305,6 +307,39 @@ sub number($;@) {
     );
 }
 
+sub float($;@) {
+    my ($num, @args) = @_;
+    my @caller = caller;
+    return Test2::Compare::Float->new(
+        file  => $caller[1],
+        lines => [$caller[2]],
+        input => $num,
+        @args,
+    );
+}
+
+sub rounded($$) {
+    my ($num, $precision) = @_;
+    my @caller = caller;
+    return Test2::Compare::Float->new(
+        file      => $caller[1],
+        lines     => [$caller[2]],
+        input     => $num,
+        precision => $precision,
+    );
+}
+
+sub within($;$) {
+    my ($num, $tolerance) = @_;
+    my @caller = caller;
+    return Test2::Compare::Float->new(
+        file      => $caller[1],
+        lines     => [$caller[2]],
+        input     => $num,
+        defined $tolerance ? ( tolerance => $tolerance ) : (),
+    );
+}
+
 sub bool($;@) {
     my ($bool, @args) = @_;
     my @caller = caller;
@@ -328,7 +363,7 @@ sub string($;@) {
 }
 
 sub filter_items(&) {
-    my $build = get_build() or croak "No current build!";
+    defined( my $build = get_build() ) or croak "No current build!";
 
     croak "'$build' does not support filters"
         unless $build->can('add_filter');
@@ -340,7 +375,7 @@ sub filter_items(&) {
 }
 
 sub all_items {
-    my $build = get_build() or croak "No current build!";
+    defined( my $build = get_build() ) or croak "No current build!";
 
     croak "'$build' does not support all-items"
         unless $build->can('add_for_each');
@@ -352,7 +387,7 @@ sub all_items {
 }
 
 sub all_keys {
-    my $build = get_build() or croak "No current build!";
+    defined( my $build = get_build() ) or croak "No current build!";
 
     croak "'$build' does not support all-keys"
         unless $build->can('add_for_each_key');
@@ -365,7 +400,7 @@ sub all_keys {
 
 *all_vals = *all_values;
 sub all_values {
-    my $build = get_build() or croak "No current build!";
+    defined( my $build = get_build() ) or croak "No current build!";
 
     croak "'$build' does not support all-values"
         unless $build->can('add_for_each_val');
@@ -378,7 +413,7 @@ sub all_values {
 
 
 sub end() {
-    my $build = get_build() or croak "No current build!";
+    defined( my $build = get_build() ) or croak "No current build!";
 
     croak "'$build' does not support 'ending'"
         unless $build->can('ending');
@@ -390,7 +425,7 @@ sub end() {
 }
 
 sub etc() {
-    my $build = get_build() or croak "No current build!";
+    defined( my $build = get_build() ) or croak "No current build!";
 
     croak "'$build' does not support 'ending'"
         unless $build->can('ending');
@@ -403,7 +438,7 @@ sub etc() {
 
 my $_call = sub {
     my ($name, $expect, $context, $func_name) = @_;
-    my $build = get_build() or croak "No current build!";
+    defined( my $build = get_build() ) or croak "No current build!";
 
     croak "'$build' does not support method calls"
         unless $build->can('add_call');
@@ -430,7 +465,7 @@ sub call_hash($$) { $_call->(@_,'hash','call_hash') }
 
 sub prop($$) {
     my ($name, $expect) = @_;
-    my $build = get_build() or croak "No current build!";
+    defined( my $build = get_build() ) or croak "No current build!";
 
     croak "'$build' does not support meta-checks"
         unless $build->can('add_prop');
@@ -453,7 +488,7 @@ sub item($;$) {
     my @args   = @_;
     my $expect = pop @args;
 
-    my $build = get_build() or croak "No current build!";
+    defined( my $build = get_build() ) or croak "No current build!";
 
     croak "'$build' does not support array item checks"
         unless $build->can('add_item');
@@ -474,7 +509,7 @@ sub item($;$) {
 sub field($$) {
     my ($name, $expect) = @_;
 
-    my $build = get_build() or croak "No current build!";
+    defined( my $build = get_build() ) or croak "No current build!";
 
     croak "'$build' does not support hash field checks"
         unless $build->can('add_field');
@@ -496,7 +531,7 @@ sub field($$) {
 sub check($) {
     my ($check) = @_;
 
-    my $build = get_build() or croak "No current build!";
+    defined( my $build = get_build() ) or croak "No current build!";
 
     croak "'$build' is not a check-set"
         unless $build->can('add_check');
@@ -543,7 +578,7 @@ sub fail_events($;$) {
 
     return ($event, $diag) if defined wantarray;
 
-    my $build = get_build() or croak "No current build!";
+    defined( my $build = get_build() ) or croak "No current build!";
     $build->add_item($event);
     $build->add_item($diag);
 }
@@ -600,7 +635,7 @@ sub event($;$) {
 
     return $event if defined wantarray;
 
-    my $build = get_build() or croak "No current build!";
+    defined( my $build = get_build() ) or croak "No current build!";
     $build->add_item($event);
 }
 
@@ -657,7 +692,7 @@ the field.
     use Test2::Tools::Compare qw{
         is like isnt unlike
         match mismatch validator
-        hash array bag object meta number string subset bool
+        hash array bag object meta number float rounded within string subset bool
         in_set not_in_set check_set
         item field call call_list call_hash prop check all_items all_keys all_vals all_values
         etc end filter_items
@@ -744,11 +779,11 @@ means '2.0' and '2' will match.
 Opposite of C<is()>. Does all the same checks, but passes when there is a
 mismatch.
 
-=item like($got, $expect)
+=item $bool = like($got, $expect)
 
-=item like($got, $expect, $name)
+=item $bool = like($got, $expect, $name)
 
-=item like($got, $expect, $name, @diag)
+=item $bool = like($got, $expect, $name, @diag)
 
 C<$got> is the data structure you want to check. C<$expect> is what you want
 C<$got> to look like. C<$name> is an optional name for the test. C<@diag> is
@@ -775,11 +810,11 @@ to compare two strings:
 
     like('foo bar', qr/^foo/, "string matches the pattern");
 
-=item unlike($got, $expect)
+=item $bool = unlike($got, $expect)
 
-=item unlike($got, $expect, $name)
+=item $bool = unlike($got, $expect, $name)
 
-=item unlike($got, $expect, $name, @diag)
+=item $bool = unlike($got, $expect, $name, @diag)
 
 Opposite of C<like()>. Does all the same checks, but passes when there is a
 mismatch.
@@ -951,6 +986,53 @@ Verify that the value matches the given number using the C<==> operator.
 
 Verify that the value does not match the given number using the C<!=> operator.
 
+=item $check = float ...;
+
+Verify that the value is approximately equal to the given number.
+
+If a 'precision' parameter is specified, both operands will be
+rounded to 'precision' number of fractional decimal digits and
+compared with C<eq>.
+
+Otherwise, the check will be made within a range of +/- 'tolerance',
+with a default 'tolerance' of 1e-08.
+
+See also C<within> and C<rounded>.
+
+=item $check = !float ...;
+
+Verify that the value is not approximately equal to the given number.
+
+If a 'precision' parameter is specified, both operands will be
+rounded to 'precision' number of fractional decimal digits and
+compared with C<eq>.
+
+Otherwise, the check will be made within a range of +/- 'tolerance',
+with a default 'tolerance' of 1e-08.
+
+See also C<!within> and C<!rounded>.
+
+=item $check = within($num, $tolerance);
+
+Verify that the value approximately matches the given number,
+within a range of +/- C<$tolerance>.  Compared using the C<==> operator.
+
+C<$tolerance> is optional and defaults to 1e-08.
+
+=item $check = !within($num, $tolerance);
+
+Verify that the value does not approximately match the given number within a range of +/- C<$tolerance>.  Compared using the C<!=> operator.
+
+C<$tolerance> is optional and defaults to 1e-08.
+
+=item $check = rounded($num, $precision);
+
+Verify that the value approximately matches the given number, when both are rounded to C<$precision> number of fractional digits. Compared using the C<eq> operator.
+
+=item $check = !rounded($num, $precision);
+
+Verify that the value does not approximately match the given number, when both are rounded to C<$precision> number of fractional digits. Compared using the C<ne> operator.
+
 =item $check = bool ...;
 
 Verify the value has the same boolean value as the given argument (XNOR).
@@ -1639,7 +1721,7 @@ has custom diagnostics you will need to add checks for them.
 =head1 SOURCE
 
 The source code repository for Test2-Suite can be found at
-F<http://github.com/Test-More/Test2-Suite/>.
+F<https://github.com/Test-More/Test2-Suite/>.
 
 =head1 MAINTAINERS
 
@@ -1659,7 +1741,7 @@ F<http://github.com/Test-More/Test2-Suite/>.
 
 =head1 COPYRIGHT
 
-Copyright 2016 Chad Granum E<lt>exodist@cpan.orgE<gt>.
+Copyright 2018 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
